summaryrefslogtreecommitdiffstats
path: root/StdLib/LibC/String/Copying.c
diff options
context:
space:
mode:
Diffstat (limited to 'StdLib/LibC/String/Copying.c')
-rw-r--r--StdLib/LibC/String/Copying.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/StdLib/LibC/String/Copying.c b/StdLib/LibC/String/Copying.c
index e27519e24c..96be24b9a9 100644
--- a/StdLib/LibC/String/Copying.c
+++ b/StdLib/LibC/String/Copying.c
@@ -19,12 +19,12 @@
#include <stdlib.h>
#include <string.h>
/** Do not define memcpy for IPF+GCC or ARM+GCC builds.
For IPF, using a GCC compiler, the memcpy function is converted to
CopyMem by objcpy during build.
- For ARM, the memcpy function is provided by the CompilerIntrinsics library.
+ For ARM/AARCH64, the memcpy function is provided by the CompilerIntrinsics library.
**/
-#if !((defined(MDE_CPU_IPF) || defined(MDE_CPU_ARM)) && defined(__GNUC__))
+#if !((defined(MDE_CPU_IPF) || defined(MDE_CPU_ARM) || defined(MDE_CPU_AARCH64)) && defined(__GNUC__))
/** The memcpy function copies n characters from the object pointed to by s2
into the object pointed to by s1.
@@ -19,12 +19,12 @@
#include <stdlib.h>
#include <string.h>
-/** Do not define memcpy for IPF+GCC or ARM+GCC builds.
+/** Do not define memcpy for IPF+GCC or ARM/AARCH64+GCC builds.
For IPF, using a GCC compiler, the memcpy function is converted to
CopyMem by objcpy during build.